Attribute VB_Name = "DeskDemo"
Option Explicit ' Force explicit variable declaration.

Declare Function GetDesktopWindow Lib "user32" () As Long
Declare Function FindWindowEx Lib "user32" Alias "FindWindowExA" (ByVal hWnd1 As Long, ByVal hWnd2 As Long, ByVal lpsz1 As String, ByVal lpsz2 As String) As Long
Declare Function SendMessage Lib "user32" Alias "SendMessageA" (ByVal hwnd As Long, ByVal wMsg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Declare Function InvalidateRect Lib "user32" (ByVal hwnd As Long, ByVal lpRect As Long, ByVal bErase As Long) As Long

' List-view control messages
Const lvm_First = &H1000
Const lvm_GetItemCount = lvm_First + 4      ' get item count
Const lvm_GetTextColor = lvm_First + 35     ' get text foreground color
Const lvm_SetTextColor = lvm_First + 36     ' set text foreground color
Const lvm_GetTextBkColor = lvm_First + 37   ' get text background color
Const lvm_SetTextBkColor = lvm_First + 38   ' set text background color

' Windows API messages

Public Const wm_SetFont = &H30
Public Const wm_GetFont = &H31

' This function searches for the Desktop List-View and
' returns the API-level window handle for the control
Function GetDesktopListView() As Long
    Dim Wnd As Long
    ' Assume the worst!
    GetDesktopListView = 0
    ' Start by getting the desktop itself
    Wnd = GetDesktopWindow
    ' Now get the hidden shell window
    If Wnd <> 0 Then Wnd = FindWindowEx(Wnd, 0, "Progman", "Program Manager")
    ' Now get the shell default view
    If Wnd <> 0 Then Wnd = FindWindowEx(Wnd, 0, "SHELLDLL_DefView", vbNullString)
    ' Finally get the list-view itself
    If Wnd <> 0 Then GetDesktopListView = FindWindowEx(Wnd, 0, "SysListView32", vbNullString)
End Function

' This function returns the number of items on the Desktop
Function GetDesktopItemCount() As Long
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd = 0 Then
        GetDesktopItemCount = 0
    Else
        GetDesktopItemCount = SendMessage(Wnd, lvm_GetItemCount, 0, 0)
    End If
End Function

'This function returns the current text background colour for the Desktop
Function GetDesktopTextBackgroundColor() As Long
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd = 0 Then
        GetDesktopTextBackgroundColor = 0
    Else
        GetDesktopTextBackgroundColor = SendMessage(Wnd, lvm_GetTextBkColor, 0, 0)
    End If
End Function

'This function returns the current text foreground colour for the Desktop
Function GetDesktopTextForegroundColor() As Long
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd = 0 Then
        GetDesktopTextForegroundColor = 0
    Else
        GetDesktopTextForegroundColor = SendMessage(Wnd, lvm_GetTextColor, 0, 0)
    End If
End Function

'This procedure sets the current text background color for the Desktop
Sub SetDesktopTextBackgroundColor(Color As Long)
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd <> 0 Then
        SendMessage Wnd, lvm_SetTextBkColor, 0, Color
        InvalidateRect Wnd, 0, True
    End If
End Sub

'This procedure sets the current text foreground color for the Desktop
Sub SetDesktopTextForegroundColor(Color As Long)
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd <> 0 Then
        SendMessage Wnd, lvm_SetTextColor, 0, Color
        InvalidateRect Wnd, 0, True
    End If
End Sub

'This procedure sets the font used by the Desktop
Sub SetDesktopFont(Font As Long)
    Dim Wnd As Long
    Wnd = GetDesktopListView
    If Wnd <> 0 Then SendMessage Wnd, wm_SetFont, Font, 1
End Sub


