VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "cCategories"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
Attribute VB_Ext_KEY = "SavedWithClassBuilder" ,"Yes"
Attribute VB_Ext_KEY = "Collection" ,"Category"
Attribute VB_Ext_KEY = "Member0" ,"DiaryItems"
Attribute VB_Ext_KEY = "Top_Level" ,"Yes"
Option Explicit

'Private variable to hold the collection of objects of cCategory
Private mcolCategories As Collection

Private Sub Class_Initialize()
    'Create the collection when an object of this class is created
    Set mcolCategories = New Collection
    
    'Set up the FlexGrid on the form
    With gfrmPlanner.flxCategories
        .Rows = 1                           'Add the row for the caption
        .TextMatrix(0, 0) = "Categories"    'Set the caption
        .RowHeight(0) = 330                 'Height of 1st row
        .ColWidth(0) = 1300                 'Width of text column
        .ColWidth(1) = 345                  'Width of color patch column
    End With
    
    'Retrieve the categories and colors from the registry
    Call RetrieveCategories
End Sub


Private Sub Class_Terminate()
    'Called when an object of this class is destroyed
    'Will happen when the program ends normally
    Dim objCategory As cCategory            'Temp variable
    
    
    For Each objCategory In mcolCategories
        'For each category in the collection
        
        With objCategory
            'Save the name and color in the registry
            SaveSetting App.Title, "Categories", .Name, .Color
        End With
    
    Next objCategory
    
    'destroy the collection
    'This will destroy all the objects in the collection
    Set mcolCategories = Nothing
End Sub


Private Sub RetrieveCategories()
    'Reads all the categories from Outlook's Master Category List
    Dim strCategories   As String   'String of names and ;
    Dim strCategory     As String   'A name
    Dim lngColor        As Long     'The color for a category
    Dim lngLength       As Long     'The length of the categories string
    Dim lngSeparator    As Long     'Where the ; character appears next
    Dim lngKey          As Long     'A point in the registry
    Dim lngResult       As Long     'Result of the registry functions
    
    'Open the registry where Outlook stores its Master Category List
    lngResult = RegOpenKey(HKEY_CURRENT_USER, "Software\Microsoft\Office\8.0\Outlook", lngKey)
    
    'Read how long the list is
    lngResult = RegQueryValue(lngKey, "Categories", strCategories, lngLength)
    
    'Make a string variable for this length
    strCategories = Space$(lngLength)
    
    'Retrieve the string of categories
    lngResult = RegQueryValue(lngKey, "Categories", strCategories, lngLength)
    
    'Close the registry
    lngResult = RegCloseKey(lngKey)
    
    'Find the first ; character in the string
    lngSeparator = InStr(strCategories, ";")
    
    Do While lngSeparator   'While there's another ; character
        'Get the next category name (up to the ; character)
        strCategory = Left$(strCategories, lngSeparator - 1)
        
        'Read the color for this category that was saved last time
        'If we've not seen this category before then assume it was green
        lngColor = GetSetting(App.Title, "Categories", strCategory, vbGreen)
        
        'Add this category and color to our collection
        Add strCategory, lngColor
        'This calls the Add method below
        
        'Move on to the next category in the list
        strCategories = Mid$(strCategories, lngSeparator + 1)
        lngSeparator = InStr(strCategories, ";")
    Loop
    
End Sub


Public Function Add(Name As String, Color As Long) As cCategory
    'This is called when we want to add a new category
    'to the collection
    
    'A variable to hold the new object
    Dim objNewCategory As cCategory
    
    'create the new object
    Set objNewCategory = New cCategory
    
    'set the properties of the object
    objNewCategory.Name = Name
    objNewCategory.Color = Color
        
    'Add the new object to our collection
    'using the category name as the key
    mcolCategories.Add objNewCategory, Name
    
    'We must now have more than one row in the
    'flexgrid so we can make the top row fixed
    'to show the caption
    With gfrmPlanner.flxCategories
        .FixedRows = 1
        .Refresh
    End With
    
    'return the newly created object
    Set Add = objNewCategory
    
    'We can now destroy our pointer to it
    'It is safely inside the collection so
    'it won't disappear
    Set objNewCategory = Nothing
End Function


Public Property Get Item(vntIndexKey As Variant) As cCategory
Attribute Item.VB_UserMemId = 0
    'Called when referencing an element in the collection
    'vntIndexKey contains either the Index (numeric)
    'or Key (string) to the collection,
    'this is why it is declared as a Variant
    
    'Ignore any errors
    On Error Resume Next
    
    'Return the item
    Set Item = mcolCategories(vntIndexKey)
    
End Property


Public Property Get Count() As Long
    'Returns the number of items in the collection
    Count = mcolCategories.Count
End Property


Public Sub Remove(vntIndexKey As Variant)
    'Removes an item from the collection
    'You can pass either the item index number
    'or the key (name) of the item
    
    mcolCategories.Remove vntIndexKey
End Sub


Public Property Get NewEnum() As IUnknown
Attribute NewEnum.VB_UserMemId = -4
Attribute NewEnum.VB_MemberFlags = "40"
    'this property allows you to enumerate
    'this collection with the For...Each syntax
    'It is a bit of magic
    Set NewEnum = mcolCategories.[_NewEnum]
End Property


